Welcome to ycsettings's documentation!
======================================

.. include:: ../README.rst

Table of Contents:

.. toctree::
   :maxdepth: 2

   settings
   installation

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
